@@ -12,10 +12,10 @@ from typing import Dict, List, Union, Optional
 from rich.pretty import pprint
 import pandas as pd
 
-from halib import *
+# from halib import *
 # internal imports
-# from ..filetype import csvfile
-# from ..common import ConsoleLog
+from ..filetype import csvfile
+from ..common import ConsoleLog
 
 
 class DatasetMetrics:
